@@ -49,6 +49,7 @@ my $configure_gnusocial=sub {
    my $cnt=$_[1];
    my $selection=$_[2]||'';
    my $region=$_[4]||'';
+   my $verified_email=$_[5]||'';
    my $handle=$main::aws->{$server_type}->[$cnt]->[1];
    my ($stdout,$stderr)=('','');
    ($stdout,$stderr)=$handle->cmd("sudo yum -y update",'__display__');
@@ -640,7 +641,6 @@ END
       "export AWS_SECRET_ACCESS_KEY=$hash->{AccessKey}->{SecretAccessKey}");
    my $smtppass='';
    ($smtppass,$stderr)=$handle->cmd("java SesSmtpCredentialGenerator");
-print "SMTPPASS=$smtppass and STDERR=$stderr and $hash->{AccessKey}->{AccessKeyId} and SEC=$hash->{AccessKey}->{SecretAccessKey}\n";
    use LWP::UserAgent;
    use HTTP::Request::Common;
    use IO::Socket::SSL qw();
@@ -664,7 +664,7 @@ print "SMTPPASS=$smtppass and STDERR=$stderr and $hash->{AccessKey}->{AccessKeyI
          'admin_nickname' => 'admin',
          'admin_password' => 'admin',
          'admin_password2' => 'admin',
-         'admin_email' => 'brian.kelly@fullauto.com',
+         'admin_email' => $verified_email,
          'site_profile' => 'public',
          'submit' => 'Submit',
       ],
@@ -713,7 +713,7 @@ END
          }
       }
    }
-print "SMTP SERVER = $smtp_server\n";
+print "SMTP SERVER = $smtp_server and VERIFIED_EMAIL = $verified_email\n\n";
    print "\n   ACCESS GNU SOCIAL UI AT:\n\n",
          " https://$public_ip/index.php\n";
    my $thanks=<<'END';
@@ -756,6 +756,10 @@ my $standup_gnusocial=sub {
    my $region="]T[{awsregions}";
    $region=~s/^"//;
    $region=~s/"$//;
+   my $verified_email="]T[{pick_email}";
+   if (-1<index $verified_email,'Enter ') {
+      $verified_email="]I[{'gnusocial_enter_email_address',1}";
+   }
    my $gnusocial="]T[{select_gnusocial_setup}";
    my $i=$main::aws->{fullauto}->{ImageId}||'';
    my $s=$main::aws->{fullauto}->
@@ -805,12 +809,12 @@ my $standup_gnusocial=sub {
          "--security-group-ids $g --subnet-id $s";
       if ($#{$main::aws->{'GNU.io/Social'}}==0) {
          launch_server('GNU.io/Social',$cnt,$gnusocial,'',$c,
-         $configure_gnusocial,'',$region);
+         $configure_gnusocial,'',$region,$verified_email);
       } else {
          my $num=$#{$main::aws->{'GNU.io/Social'}}-1;
          foreach my $num (0..$num) {
             launch_server('GNU.io/Social',$cnt++,$gnusocial,'',$c,
-            $configure_gnusocial,'',$region);
+            $configure_gnusocial,'',$region,$verified_email);
          }
       }
    }
@@ -909,9 +913,61 @@ END
 
 };
 
+our $gnusocial_validate_email=sub {
+
+   my $email="]I[{'gnusocial_enter_email_address',1}";
+   my $confirm="]I[{'gnusocial_enter_email_address',2}";
+   unless ($email eq $confirm) {
+      STDOUT->autoflush(1);
+      print "\n   ERROR: Email Addresses do not match!";sleep 5;
+      STDOUT->autoflush(0);
+      return '<';
+   } elsif ($email!~/\@/) {
+      STDOUT->autoflush(1);
+      print "\n   ERROR: Email Address must contain '@' character!";sleep 5;
+      STDOUT->autoflush(0);
+      return '<';
+   } elsif ($email=~/^\s*$/) {
+      STDOUT->autoflush(1);
+      print "\n   ERROR: You failed to enter an Email Address!";sleep 5;
+      STDOUT->autoflush(0);
+      return '<';
+   }
+   my $c="aws ses verify-email-identity --email-address $email";
+   my ($hash,$output,$error)=run_aws_cmd($c);
+   my $inform_banner=<<'END';
+
+    ___                     _            _   _
+   |_ _|_ __  _ __  ___ _ _| |_ __ _ _ _| |_| |
+    | || '  \| '_ \/ _ \ '_|  _/ _` | ' \  _|_|
+   |___|_|_|_| .__/\___/_|  \__\__,_|_||_\__(_)
+             |_|
+
+END
+   $inform_banner.=<<END;
+   The email address you just entered: $email
+
+   has been submitted to Amazon Web Services for verification. Amazon
+   will be sending an email to this address that you must respond to
+   in order for this address to work with your GNU Social installation.
+   You can take a few minutes to do this now, or after you complete this
+   installation. Just note, that email in you GNU Social server will
+   not work until you have responded to Amazon's email.
+
+END
+   my $email_message={
+
+      Name => 'email_message',
+      Result => $gnusocial_setup_summary,
+      Banner => $inform_banner,
+
+   };
+   return $email_message;
+
+};
+
 our $gnusocial_enter_email_address=sub {
 
-   my @options=('GNU Social & MySQL & NGINX on 1 Server');
    my $gnusocial_email_banner=<<'END';
 
     ___     _             ___            _ _     _      _    _
@@ -919,26 +975,92 @@ our $gnusocial_enter_email_address=sub {
    | _|| ' \  _/ -_) '_| | _|| '  \/ _` | | |  / _ \/ _` / _` | '_/ -_|_-<_-<
    |___|_||_\__\___|_|   |___|_|_|_\__,_|_|_| /_/ \_\__,_\__,_|_| \___/__/__/
 
+END
+   $gnusocial_email_banner.=<<END;
+
+   Type or Copy & Paste the main contact email for GNU Social here:
+
+   (Use [TAB] key to switch between input boxes)
+
+
+   Email Address
+                    ]I[{1,'',50}
+
+   Confirm Address
+                    ]I[{2,'',50}
 
 
 END
-   my %select_gnusocial_setup=(
 
-      Name => 'select_gnusocial_setup',
-      Item_1 => {
+   my $gnusocial_enter_email_address={
 
-         Text => ']C[',
-         Convey => \@options,
-         Result => $gnusocial_setup_summary,
-
-      },
-      Scroll => 1,
+      Name => 'gnusocial_enter_email_address',
+      Input => 1,
+      Result => $gnusocial_validate_email,
+      #Result => $gnusocial_setup_summary,
       Banner => $gnusocial_email_banner,
-   );
-   return \%select_gnusocial_setup
+
+   };
+   return $gnusocial_enter_email_address;
 
 };
 
+our $gnusocial_pick_email_address=sub {
+
+   package gnusocial_pick_email_address;
+   use Net::FullAuto::Cloud::fa_amazon;
+   my $c="aws ses list-identities";
+   my ($hash,$output,$error)=run_aws_cmd($c);
+   my @identities=grep { /\@/ } @{$hash->{Identities}};
+   if (-1<$#identities) {
+
+      my $pick_banner=<<'END';
+
+    ___ _    _     ___            _ _     _      _    _
+   | _ (_)__| |__ | __|_ __  __ _(_) |   /_\  __| |__| |_ _ ___ ______
+   |  _/ / _| / / | _|| '  \/ _` | | |  / _ \/ _` / _` | '_/ -_|_-<_-<
+   |_| |_\__|_\_\ |___|_|_|_\__,_|_|_| /_/ \_\__,_\__,_|_| \___/__/__/
+END
+      $pick_banner.=<<'END';
+
+   In order for email functionality to work with GNU Social, you need to
+   associate an Amazon Web Services verified email address. The following
+   email addresses have been identified as verifed Amazon addresses. Please
+   select one, or choose to create a new one. Note that if you choose to
+   create a new one, it will have to be verified before email functionality
+   in GNU Social will work properly. This setup wizard will notify Amazon,
+   and Amazon will send an email to the entered address. You must respond to
+   that email in order to complete verification. You can also verify
+   addresses manually at this Amazon URL:
+
+http://docs.aws.amazon.com/ses/latest/DeveloperGuide/verify-email-addresses.html
+
+END
+      my $pick_email={
+      
+         Name => 'pick_email',
+         Item_1 => {
+
+            Text => "Enter and verify a different address\n\n",
+            Result =>
+      $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_email_address->(),
+
+         },
+         Item_2 => {
+
+            Text => "]C[",
+            Convey => \@identities,
+            Result => $gnusocial_setup_summary,
+
+         },    
+         Banner => $pick_banner,
+      };
+      return $pick_email;
+   } else {
+      $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_email_address->();
+   }
+
+};
 
 our $select_gnusocial_setup=sub {
 
@@ -955,11 +1077,10 @@ our $select_gnusocial_setup=sub {
             \_/        \____|_| \_|\___/    |____/ \___/ \___|_|\__,_|_|
 
 
-   Choose the GNU Social setup you wish to set up. Note that more servers
-   means more expense, and more JVMs means less permformance on a
-   small instance type. Consider a medium or large instance type (previous
-   screens) if you wish to test more than 1 JVM on a server. You can
-   navigate backwards and make new selections with the [<] LEFTARROW key.
+   Choose the GNU Social setup you wish to set up. Note that more or larger
+   capactiy servers means more expense. Consider a medium or large instance
+   type (previous screens) if you foresee a lot of traffic on the server. You
+   can navigate backwards and make new selections with the [<] LEFTARROW key.
 
 END
    my %select_gnusocial_setup=(
@@ -969,8 +1090,7 @@ END
 
          Text => ']C[',
          Convey => \@options,
-         #Result => $gnusocial_setup_summary,
-         Result => $gnusocial_enter_email_address,
+         Result => $gnusocial_pick_email_address,
 
       },
       Scroll => 1,
